Install `python-lzo`
--------------------
- **On Linux**
	+ Make sure `liblzo2-dev` or `liblzo2-devel` is installed.
	+ Run `sudo pip3 install python-lzo`

- **On Android with Termux**
	+ `apt install liblzo`
	+ `pip install python-lzo`

- **On Windows**:
	+ Open this page: https://www.lfd.uci.edu/~gohlke/pythonlibs/#python-lzo
	+ If you are using Python 3.7 (32 bit) for example, click on `python_lzo‑1.12‑cp37‑cp37m‑win32.whl`
	+ Open Start -> type Command -> right-click on Command Prompt -> Run as administrator
	+ Run `pip install C:\....\python_lzo‑1.12‑cp37‑cp37m‑win32.whl` command, giving the path of downloaded file

